@@ -15,14 +15,13 @@ class Config(metaclass=SingletonMeta):
         with open(config_file, 'r', encoding='utf-8') as f:
             self.config = yaml.safe_load(f)
         self.MaxBytes = self.config.get('MaxBytes', 209715200)
-        self.Timeout = self.config.get('Timeout', 300000)
-        self.OCR = self.config.get('OCR', None)
-        self.INVOICE_OCR = self.config.get('INVOICE_OCR', None)
-        self.UnstructuredAPI = self.config.get('UnstructuredAPI', None)
+        self.Timeout = self.config.get('Timeout', 600000)
         self.MaxRetries = self.config.get('MaxRetries', 3)
         self.llm_configs = []
         self.embedding_configs = []
         self.reranker_configs = []
+        self.sentry_configs = []
+        self.langfuse_configs = []
         self._process_config()
 
     def get_llm_config(self, model_name):
@@ -43,6 +42,18 @@ class Config(metaclass=SingletonMeta):
                 return llm
         raise ValueError(f"No configuration found for model: {model_name}")
 
+    def get_sentry_config(self, name):
+        for sentry in self.sentry_configs:
+            if sentry.get('name') == name:
+                return sentry
+        raise ValueError(f"No configuration found for server: {name}")
+
+    def get_langfuse_config(self, name):
+        for langfuse in self.langfuse_configs:
+            if langfuse.get('name') == name:
+                return langfuse
+        raise ValueError(f"No configuration found for server: {name}")
+
     def _process_config(self):
         llm_config_list = self.config.get('LLMConfig', [])
         for llm_config in llm_config_list:
@@ -71,3 +82,17 @@ class Config(metaclass=SingletonMeta):
                 self.reranker_configs.append(validated_config.model_dump())
             except ValueError as e:
                 print(f"Invalid LLM configuration: {e}")
+
+        sentry_config_list = self.config.get('SentryConfig', [])
+        for sentry_config in sentry_config_list:
+            try:
+                from sycommon.config.SentryConfig import SentryConfig
+                validated_config = SentryConfig(**sentry_config)
+                self.sentry_configs.append(validated_config.model_dump())
+            except ValueError as e:
+                print(f"Invalid Sentry configuration: {e}")
+
+    def set_attr(self, share_configs: dict):
+        self.config = {**self.config, **
+                       share_configs.get('llm', {}), **share_configs}
+        self._process_config()
